@@ -1,6 +1,6 @@
-use serde::Serialize;
+use serde::Deserialize;
 
-#[derive(Serialize)]
+#[derive(Deserialize)]
 pub struct SubscribeDto { 
     pub public_key: String,
     pub password: String
